@@ -53,6 +53,7 @@ _PHOTOS_6_MODEL_VERSION = [14000, 14999]
 _PHOTOS_7_MODEL_VERSION = [15000, 15999]  # Dev preview: 15134, 12.1: 15331
 _PHOTOS_8_MODEL_VERSION = [16000, 16999]  # Ventura dev preview: 16119
 _PHOTOS_9_MODEL_VERSION = [17000, 17999]  # Sonoma dev preview: 17120
+_PHOTOS_10_MODEL_VERSION = [18000, 18999]  # Sequoia dev preview: 18164
 
 # the preview versions of 12.0.0 had a difference schema for syndication info so need to check model version before processing
 _PHOTOS_SYNDICATION_MODEL_VERSION = 15323  # 12.0.1
@@ -75,6 +76,8 @@ _DB_TABLE_NAMES = {
         "HDR_TYPE": "ZCUSTOMRENDEREDVALUE",
         "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
         "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZGENERICASSET.ZHASADJUSTMENTS",
     },
     6: {
         "ASSET": "ZASSET",
@@ -89,6 +92,8 @@ _DB_TABLE_NAMES = {
         "HDR_TYPE": "ZCUSTOMRENDEREDVALUE",
         "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
         "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
     7: {
         "ASSET": "ZASSET",
@@ -103,6 +108,8 @@ _DB_TABLE_NAMES = {
         "HDR_TYPE": "ZHDRTYPE",
         "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
         "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
     8: {
         "ASSET": "ZASSET",
@@ -117,6 +124,8 @@ _DB_TABLE_NAMES = {
         "HDR_TYPE": "ZHDRTYPE",
         "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
         "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
     9: {
         "ASSET": "ZASSET",
@@ -131,6 +140,24 @@ _DB_TABLE_NAMES = {
         "HDR_TYPE": "ZHDRTYPE",
         "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
         "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
+    },
+    10: {
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_48KEYWORDS",
+        "ALBUM_JOIN": "Z_31ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_31ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_31ASSETS.Z_31ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_31ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
+        "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
     },
 }
 
